@@ -58,7 +58,9 @@ typedef struct
 				   5 -  ftp url
 				   6 -  mailto url */
     char node[256];		/* name of the referenced node */
+    int nodelen;		/* length of string node */
     char file[256];		/* name of the referenced file -- none=this file */
+    int filelen;		/* length of string file */
     int tagtableoffset;		/* offset in tag table */
   }
 HyperObject;
