@@ -10,6 +10,9 @@ RCSID ("$Id: filehandling_functions.c,v 1.28 2000/06/07 11:27:11 pborys Exp $")
        }
 Suffixes;
 
+char * basename (char *filename);
+
+
 /******************************************************************************
 * This piece of declarations says what to do with info files stored with      *
 * different formats/compression methods, before putting them into a temporary *
@@ -39,33 +42,46 @@ Suffixes;
   return compare_tag_table_string (cbase, ccompared);
 }
 
-int 
+int
 matchfile (char **buf, char *name)
 {
 #define Buf (*buf)
-  DIR *dir = opendir (Buf);
+  DIR *dir;
+  char *bname=basename(name);
   struct dirent *dp;
-  int namelen = strlen (name);
+  int namelen = strlen (bname);
+  int matched = 0;
+  if(Buf[strlen(Buf)-1]!='/')
+    strcat(Buf,"/");
+  strncat(Buf,name,bname-name);
+  dir = opendir (Buf);	/* here we always have '/' at end */
   if (dir == NULL)
     return 1;
   while ((dp = readdir (dir)) != NULL)
     {
-      if (strncmp (dp->d_name, name, namelen) == 0)
+      if (strncmp (dp->d_name, bname, namelen) == 0)
 	{
 	  char *tmp = strdup (dp->d_name);
 	  int dl;
 	  strip_compression_suffix (tmp);
 	  dl = strlen (tmp);
-	  if (!isdigit (tmp[dl - 1]))	/* if it's not eg. info-2.gz, but info.gz, the primary page */
+	  if ((!isdigit (tmp[dl - 1])) && (!isalpha (tmp[namelen])))
+	    /* if it's not eg. info-2.gz, but info.gz, the primary page
+	     * && it's not a different name (eg. gdbm instead gdb) */
 	    {
-	      strcat (Buf, "/");
-	      strcat (Buf, tmp);
-	      closedir (dir);
-	      return 0;
+	      if ((!matched) || (strlen (tmp) < matched))
+		{
+		  Buf[strlen(Buf) - matched - 1] = '\0';
+		  strcat (Buf, "/");
+		  strcat (Buf, tmp);
+		  matched = strlen (tmp);
+		}
 	    }
 	}
     }
   closedir (dir);
+  if (matched)
+    return 0;
   return 1;
 #undef Buf
 }
@@ -749,9 +765,9 @@ addrawpath (char *filename)
     {
       if (filename[i] == '/')
 	{
-	  tmp = filename[i];
-	  filename[i] = 0;
-	  pos = i;
+	  tmp = filename[i+1];
+	  filename[i+1] = 0;
+	  pos = i+1;
 	  break;
 	}
     }
@@ -762,13 +778,13 @@ addrawpath (char *filename)
   for (i = infopathcount; i > 0; i--)	/* move entries to the right */
     infopaths[i] = infopaths[i - 1];
 
-  if (pos >= 0)
-    strcpy (infopaths[0], filename);	/* add new (raw) entry */
+  if (pos > 0)
+    infopaths[0]=strdup(filename);	/* add new (raw) entry */
   else
-    strcpy (infopaths[0], ".");
+    infopaths[0]=strdup("./");
   infopathcount++;
 
-  if (pos >= 0)			/* recreate original filename */
+  if (pos > 0)			/* recreate original filename */
     filename[pos] = tmp;
 }
 
@@ -875,9 +891,9 @@ initpaths ()
       infopaths = tmpinfopaths;
     }
 
-  infopaths[infopathcount] = xmalloc (5);
-  strcpy (infopaths[infopathcount], ".");	/* for ./ */
-  infopathcount++;
+/*  infopaths[infopathcount] = xmalloc (5); */
+/*  strcpy (infopaths[infopathcount], "."); */	/* for ./ */
+/*  infopathcount++; */
 }
 void
 create_indirect_tag_table ()
