@@ -130,7 +130,7 @@ finddot (char *str, int note)	/*
   };
   char *closest = 0;
   int i;
-  while (isspace(*ptr))	/* if there are only spaces and newline... */
+  while (isspace (*ptr))	/* if there are only spaces and newline... */
     {
       if (*ptr == '\n')		/* then it's a `Menu:   \n' entry--skip it */
 	return 0;
@@ -248,6 +248,8 @@ initializelinks (char *line1, char *line2, int line)
 			strncpy (hyperobjects[hyperobjectcount].node, quotestart + 1, quoteend - quotestart - 1);
 			hyperobjects[hyperobjectcount].node[quoteend - quotestart - 1] = 0;
 			strcpy (hyperobjects[hyperobjectcount].file, "");
+			hyperobjects[hyperobjectcount].nodelen=strlen(hyperobjects[hyperobjectcount].node);
+			hyperobjects[hyperobjectcount].filelen=strlen(hyperobjects[hyperobjectcount].file);
 			hyperobjects[hyperobjectcount].tagtableoffset = -1;
 			hyperobjectcount++;
 		      }
@@ -277,6 +279,8 @@ initializelinks (char *line1, char *line2, int line)
 	  strncpy (hyperobjects[hyperobjectcount].node, urlstart, urlend - urlstart);
 	  hyperobjects[hyperobjectcount].node[urlend - urlstart] = 0;
 	  strcpy (hyperobjects[hyperobjectcount].file, "");
+	  hyperobjects[hyperobjectcount].nodelen=strlen(hyperobjects[hyperobjectcount].node);
+ 	  hyperobjects[hyperobjectcount].filelen=strlen(hyperobjects[hyperobjectcount].file);
 	  hyperobjects[hyperobjectcount].tagtableoffset = -1;
 	  if (strchr (hyperobjects[hyperobjectcount].node, '.') == NULL)
 	    {
@@ -325,6 +329,8 @@ initializelinks (char *line1, char *line2, int line)
 		  hyperobjects[hyperobjectcount].line = line;
 		  hyperobjects[hyperobjectcount].col = 2;
 		  hyperobjects[hyperobjectcount].breakpos = -1;
+		  hyperobjects[hyperobjectcount].nodelen=strlen(hyperobjects[hyperobjectcount].node);
+ 		  hyperobjects[hyperobjectcount].filelen=strlen(hyperobjects[hyperobjectcount].file);
 		  hyperobjectcount++;
 		}
 	    }
@@ -341,6 +347,8 @@ initializelinks (char *line1, char *line2, int line)
 	      hyperobjects[hyperobjectcount].line = line;
 	      hyperobjects[hyperobjectcount].col = 2;
 	      hyperobjects[hyperobjectcount].breakpos = -1;
+	      hyperobjects[hyperobjectcount].nodelen=strlen(hyperobjects[hyperobjectcount].node);
+	      hyperobjects[hyperobjectcount].filelen=strlen(hyperobjects[hyperobjectcount].file);
 	      if (exists_in_tag_table (hyperobjects[hyperobjectcount].node))
 		{
 		  hyperobjectcount++;	/* yep, this was a good hit */
@@ -370,11 +378,11 @@ initializelinks (char *line1, char *line2, int line)
 		if (strncmp (dot, ".info)", 6) == 0)	/* skip possible '.info' filename suffix when searching for ending dot */
 		  dot = finddot (dot + 1, MENU_DOT);
 	      }
-	  if (((start = strchr (tmp, '(')) != NULL) && (dot != NULL))
+	  if (((start = strchr (tmp, '(')) != NULL) && (dot != NULL) &&
+	      ((end = strchr (start, ')')) != NULL))	/* we make use of sequential AND evaluation: start must not be NULL! */
 	    {
 	      if (start < dot)	/* security mechanism ;) */
 		{
-		  end = strchr (start, ')');	/* find end of file name */
 		  if (end < dot)	/* security mechanism ;)) */
 		    {
 		      long FilenameLen = (long) (end - start - 1);
@@ -393,6 +401,8 @@ initializelinks (char *line1, char *line2, int line)
 		      hyperobjects[hyperobjectcount].line = line;
 		      hyperobjects[hyperobjectcount].col = calculate_len (line1, start);
 		      hyperobjects[hyperobjectcount].breakpos = -1;
+		      hyperobjects[hyperobjectcount].nodelen=strlen(hyperobjects[hyperobjectcount].node);
+		      hyperobjects[hyperobjectcount].filelen=strlen(hyperobjects[hyperobjectcount].file);
 		      hyperobjectcount++;
 		    }
 		}
@@ -424,6 +434,8 @@ initializelinks (char *line1, char *line2, int line)
 		hyperobjects[hyperobjectcount].line = line;
 		hyperobjects[hyperobjectcount].col = calculate_len (line1, start);
 		hyperobjects[hyperobjectcount].breakpos = -1;
+	        hyperobjects[hyperobjectcount].nodelen=strlen(hyperobjects[hyperobjectcount].node);
+	        hyperobjects[hyperobjectcount].filelen=strlen(hyperobjects[hyperobjectcount].file);
 		if (exists_in_tag_table (hyperobjects[hyperobjectcount].node))
 		  {
 		    hyperobjectcount++;		/* yep, this was a good hit */
@@ -495,6 +507,8 @@ initializelinks (char *line1, char *line2, int line)
 			  else if ((hyperobjects[hyperobjectcount].breakpos = strlen (line1) - (long) (notestart + 7 - buf) + 1) == 0)
 			    hyperobjects[hyperobjectcount].line--;
 			}
+	      	      hyperobjects[hyperobjectcount].nodelen=strlen(hyperobjects[hyperobjectcount].node);
+	              hyperobjects[hyperobjectcount].filelen=strlen(hyperobjects[hyperobjectcount].file);
 		      hyperobjectcount++;
 		    }
 		}
@@ -508,6 +522,8 @@ initializelinks (char *line1, char *line2, int line)
 			   notestart + 6, NodenameLen);
 		  hyperobjects[hyperobjectcount].node[NodenameLen] = 0;
 		  hyperobjects[hyperobjectcount].type = 2;
+      	          hyperobjects[hyperobjectcount].nodelen=strlen(hyperobjects[hyperobjectcount].node);
+                  hyperobjects[hyperobjectcount].filelen=strlen(hyperobjects[hyperobjectcount].file);
 		  if (notestart + 7 - buf < strlen (line1))
 		    {
 		      hyperobjects[hyperobjectcount].line = line;
@@ -555,11 +571,11 @@ initializelinks (char *line1, char *line2, int line)
 		    if (strncmp (dot, ".info)", 6) == 0)
 		      dot = finddot (dot + 1, NOTE_DOT);
 		  }
-	      if (((start = strchr (tmp, '(')) != NULL) && (dot != NULL))
+	      if (((start = strchr (tmp, '(')) != NULL) && (dot != NULL) &&
+		  ((end = strchr (start, ')')) != NULL))	/* end may be found only if start is nonNULL!!! */
 		{
 		  if (start < dot)	/* security mechanism ;) */
 		    {
-		      end = strchr (start, ')');	/* find end of file name */
 		      if (end < dot)	/* security mechanism ;)) */
 			{
 			  long FilenameLen = (long) (end - start - 1);
@@ -590,6 +606,8 @@ initializelinks (char *line1, char *line2, int line)
 			      hyperobjects[hyperobjectcount].col = calculate_len (buf + strlen (line1), start);
 			      hyperobjects[hyperobjectcount].breakpos = -1;
 			    }
+			  hyperobjects[hyperobjectcount].nodelen=strlen(hyperobjects[hyperobjectcount].node);
+			  hyperobjects[hyperobjectcount].filelen=strlen(hyperobjects[hyperobjectcount].file);
 			  hyperobjectcount++;
 			}
 		    }
@@ -618,6 +636,8 @@ initializelinks (char *line1, char *line2, int line)
 			     start, NodenameLen);
 		    hyperobjects[hyperobjectcount].node[NodenameLen] = 0;
 		    hyperobjects[hyperobjectcount].type = 3;
+		    hyperobjects[hyperobjectcount].nodelen=strlen(hyperobjects[hyperobjectcount].node);
+		    hyperobjects[hyperobjectcount].filelen=strlen(hyperobjects[hyperobjectcount].file);
 		    if (start - buf < strlen (line1))
 		      {
 			hyperobjects[hyperobjectcount].line = line;
@@ -684,6 +704,8 @@ initializelinks (char *line1, char *line2, int line)
       hyperobjects[hyperobjectcount].node[urlend - urlstart] = 0;
       strcpy (hyperobjects[hyperobjectcount].file, "");
       hyperobjects[hyperobjectcount].tagtableoffset = -1;
+      hyperobjects[hyperobjectcount].nodelen=strlen(hyperobjects[hyperobjectcount].node);
+      hyperobjects[hyperobjectcount].filelen=strlen(hyperobjects[hyperobjectcount].file);
       hyperobjectcount++;
     }
   /* ftp:// */
@@ -703,6 +725,8 @@ initializelinks (char *line1, char *line2, int line)
       hyperobjects[hyperobjectcount].node[urlend - urlstart] = 0;
       strcpy (hyperobjects[hyperobjectcount].file, "");
       hyperobjects[hyperobjectcount].tagtableoffset = -1;
+      hyperobjects[hyperobjectcount].nodelen=strlen(hyperobjects[hyperobjectcount].node);
+      hyperobjects[hyperobjectcount].filelen=strlen(hyperobjects[hyperobjectcount].file);
       hyperobjectcount++;
     }
   if (initialhyperobjectcount != hyperobjectcount)
