@@ -16,7 +16,7 @@ RCSID ("$Id: mainfunction.c,v 1.38 2000/01/27 11:38:15 misiek Exp $")
      int toggled_by_menu = 0;	/* this flag is turned on when the engine
 				   receives a simulated `key.back', caused
 				   by the sequential auto-pgdn reading code */
-     long pos, cursor, infomenu;
+     long pos, cursor, infomenu, infocolumn=0;
 
 WorkRVal
 work (char ***message, char **type, long *lines, FILE * id, int tag_table_pos)
@@ -92,7 +92,7 @@ work (char ***message, char **type, long *lines, FILE * id, int tag_table_pos)
   npos = -1;			/* turn off the `next-time' pos/cursor modifiers */
   ncursor = -1;
   nmenu = -1;
-  addtopline (Type);
+  addtopline (Type,infocolumn);
   while (1)
     {
       nodelay (stdscr, TRUE);	/* 
@@ -104,7 +104,7 @@ work (char ***message, char **type, long *lines, FILE * id, int tag_table_pos)
       if (key == ERR)
 	{
 	  if (statusline == FREE)
-	    showscreen (Message, Type, Lines, pos, cursor);
+	    showscreen (Message, Type, Lines, pos, cursor,infocolumn);
 	  waitforgetch ();
 	  key = pinfo_getch ();
 	}
@@ -114,7 +114,7 @@ work (char ***message, char **type, long *lines, FILE * id, int tag_table_pos)
 	{
 	  handlewinch ();
 	  winchanged = 0;
-	  addtopline (Type);
+	  addtopline (Type,infocolumn);
 	  key = pinfo_getch ();
 	}
 /***************************** keyboard handling ****************************/
@@ -1049,6 +1049,18 @@ work (char ***message, char **type, long *lines, FILE * id, int tag_table_pos)
 		      }
 		  }
 	    }
+/*==========================================================================*/
+	  if ((key == keys.left_1) || (key == keys.left_2))
+	    {
+	       if(infocolumn>0) infocolumn--;
+               addtopline (Type,infocolumn);
+	    }
+/*==========================================================================*/
+	  if ((key == keys.right_1) || (key == keys.right_2))
+	    {
+	       infocolumn++;
+               addtopline (Type,infocolumn);
+	    }
 /*==========================================================================*/
 /**************************** end of keyboard handling **********************/
 /******************************** mouse handler *****************************/
