@@ -37,6 +37,9 @@ RCSID ("$Id: manual.c,v 1.59 2000/01/27 11:38:15 misiek Exp $")
      int manualpos = 0;		/* number of the first line, which is painted on
 				   screen */
 
+     int manualcol = 0;		/* the first displayed column of manpage--
+     				   for moving the screen left/right */				   
+
      int manual_aftersearch = 0;	/* this is set if man page is now after search 
 					   operation */
      int manwidthChanged = 0;	/* this flag indicates whether the env variable
@@ -1295,6 +1298,11 @@ manualwork ()			/* viewer function. Handles keyboard actions--main event loop */
 		      }
 		  }
 	    }
+/*===========================================================================*/
+	  if((key==keys.left_1)||(key==keys.left_2))
+	    if(manualcol>0) manualcol--;
+	  if((key==keys.right_1)||(key==keys.right_2))
+	    manualcol++;
 /*===========================================================================*/
 /*********************** end of keyboard handling ***************************/
 /********************************* mouse handler *****************************/
@@ -1422,6 +1430,19 @@ rescan_selected ()		/* scan for some hyperlink, available on current screen */
     }
 }
 
+char *getmancolumn(char *man, int mancol)	/* calculate from which to
+						   start displaying of manual
+						   line *man. Skip `mancol'
+						   columns. But remember, that
+						   *man contains also nonprinteble
+						   characters for boldface etc. */
+{
+  if(mancol==0) return man;
+  while(mancol>0)
+    { if(*(man+1) == 8) man+=3; else man++; mancol--; }
+  return man;
+}
+
 void
 showmanualscreen ()		/* show the currently visible part of manpage */
 {
@@ -1436,7 +1457,14 @@ showmanualscreen ()		/* show the currently visible part of manpage */
       int len = strlen (manual[i]);
       if (len)
 	manual[i][len - 1] = ' ';
-      mvaddstr_manual ((i - manualpos) + 1, 0, manual[i]);
+      if(len>manualcol)	/* if we have something to display */
+        mvaddstr_manual ((i - manualpos) + 1, 0, getmancolumn(manual[i],manualcol));
+      else		/* otherwise, just clear the line to eol */
+        {
+          move((i - manualpos) + 1, 0);
+          bkgdset (' ' | normal);
+          clrtoeol();
+        }
       if (len)
 	manual[i][len - 1] = '\n';
     }
@@ -1558,36 +1586,41 @@ add_highlights ()		/* add hyperobject highlights */
   int i;
   for (i = 0; i < ManualLinks; i++)	/* scan through the visible objects */
     {
-      if ((manuallinks[i].line >= manualpos) &&
+      if ((manuallinks[i].line >= manualpos) &&	/* if the object is on the current screen */
 	  (manuallinks[i].line < manualpos + (maxy - 2)))
 	{
-	  if (manuallinks[i].section_mark < HTTPSECTION)
+	  if (manuallinks[i].section_mark < HTTPSECTION)	/* if it's a simple man link */
 	    {
 	      if (i == selected)
 		attrset (noteselected);
 	      else
 		attrset (note);
-	      if (manuallinks[i].carry == 1)
+	      if (manuallinks[i].carry == 1)	/* if it's a link split into two lines */
 		{
 		  int x, y, ltline = manuallinks[i].line - 1;
-		  char *tmpstr = strdup (manual[ltline]);
+		  char *tmpstr = strdup (manual[ltline]);	/* find the line, where starts the split link */
 		  int ltlinelen;
 		  char *newlinemark;
-		  strip_manual (tmpstr);
-		  ltlinelen = strlen (tmpstr);
-		  newlinemark = tmpstr + ltlinelen - 1;
+		  strip_manual (tmpstr);	/* remove boldfaces&italics */
+		  ltlinelen = strlen (tmpstr);  /* calculate the length of this line */
+		  newlinemark = tmpstr + ltlinelen - 1;	/* set this var to the last character of this line (to an '\n')*/
 		  getyx (stdscr, y, x);
 		  if (y > 2)
 		    {
 #define TestCh tmpstr[ltlinelen]
-		      if (ltlinelen > 2)
+		      if (ltlinelen > 2)	/* skip \n, -, and the at least one char... */
 			ltlinelen -= 3;
-		      while ((isalpha (TestCh)) || (TestCh == '.'))
+		      while ((isalpha (TestCh)) || (TestCh == '.'))	/* positon ltlinelen to the beginning of the link to be highlighted */
 			ltlinelen--;
 
 		      *newlinemark = 0;
-		      mvaddstr (manuallinks[i].line - manualpos + 1 - 1, ltlinelen,
-				&tmpstr[ltlinelen]);
+		      if(ltlinelen>manualcol)	/* OK, link horizontally fits into screen */
+		        mvaddstr (manuallinks[i].line - manualpos + 1 - 1, ltlinelen-manualcol,
+			  	  &tmpstr[ltlinelen]);
+		      else if(ltlinelen+strlen(&tmpstr[ltlinelen])>manualcol)	/* we cut here a part of the link, and draw only what's visible on screen */
+		        mvaddstr (manuallinks[i].line - manualpos + 1 - 1, ltlinelen-manualcol,
+			  	  &tmpstr[manualcol]);
+		      
 		      *newlinemark = '\n';
 #undef TestCh
 		    }
@@ -1604,17 +1637,23 @@ add_highlights ()		/* add hyperobject highlights */
 	      if (manuallinks[i].carry == 1)
 		{
 		  int x, y, ltline = manuallinks[i].line + 1;
-		  char *tmpstr = strdup (manual[ltline]);
+		  char *tmpstr = strdup (manual[ltline]);	/* the split part to find is lying down to the line defined in manlinks (line+1) */
 		  char *wsk = tmpstr, *wskend;
 		  strip_manual (tmpstr);
 		  while (isspace (*wsk))
 		    wsk++;	/* skip spaces */
 		  wskend = findurlend (wsk);	/* find the end of url */
 		  *wskend = 0;	/* add end of string, and print */
-		  mvaddstr (manuallinks[i].line - manualpos + 2, wsk - tmpstr, wsk);
+		  if(wsk-tmpstr<manualcol)
+		    mvaddstr (manuallinks[i].line - manualpos + 2, wsk - tmpstr - manualcol, wsk);
+		  else if(wskend-tmpstr<manualcol)
+		    mvaddstr (manuallinks[i].line - manualpos + 2, 0, wsk+manualcol);
 		}
 	    }
-	  mvaddstr (1 + manuallinks[i].line - manualpos, manuallinks[i].col, manuallinks[i].name);
+	  if(manuallinks[i].col>manualcol)
+	    mvaddstr (1 + manuallinks[i].line - manualpos, manuallinks[i].col - manualcol, manuallinks[i].name);
+	  else if(manuallinks[i].col+strlen(manuallinks[i].name)>manualcol)
+	    mvaddstr (1 + manuallinks[i].line - manualpos, 0, manuallinks[i].name+(manualcol-manuallinks[i].col));
 	  attrset (normal);
 	}
     }
