@@ -53,7 +53,9 @@ RCSID ("$Id: parse_config.c,v 1.41 2000/01/27 11:38:15 misiek Exp $")
       'l', 0,			/* go to line */
       KEY_IC, 0,		/* two lines up */
       KEY_DC, 1,		/* two lines down */
-      ']', 0			/* print */
+      ']', 0, 			/* print */
+      '4', 0,			/* scroll left */
+      '6', 0			/* scroll right */
      };
 
 #ifndef NO_COLOR_CURSES
@@ -80,34 +82,46 @@ RCSID ("$Id: parse_config.c,v 1.41 2000/01/27 11:38:15 misiek Exp $")
   char line[256];
   FILE *f;
   int line_number = 0;
-  if (getenv ("HOME"))
-    home = strdup (getenv ("HOME"));
-  else
-    home = 0;
-  if (home)
+  if (rcfile != NULL)
     {
-      strcpy (config_file_name, home);
-      strcat (config_file_name, "/.pinforc");
-      if (!(f = fopen (config_file_name, "r")))
+      f = fopen (rcfile, "r");
+      if (f == NULL)
+	{
+	  fprintf (stderr, _ ("Can't open config file!\n"));
+	  exit (1);
+	}
+    }
+  else
+    {
+      if (rcfile == NULL)
+	if (getenv ("HOME"))
+	  home = strdup (getenv ("HOME"));
+	else
+	  home = 0;
+      if (home)
+	{
+	  strcpy (config_file_name, home);
+	  strcat (config_file_name, "/.pinforc");
+	  if (!(f = fopen (config_file_name, "r")))
+	    {
+	      strcpy (config_file_name, CONFIGDIR);
+	      if (!(f = fopen (config_file_name, "r")))
+		{
+		  free (home);	/* home is nonzero; see if(home) above */
+		  return 0;	/* no config file available */
+		}
+	    }
+	}
+      else
 	{
 	  strcpy (config_file_name, CONFIGDIR);
 	  if (!(f = fopen (config_file_name, "r")))
 	    {
-	      free (home);	/* home is nonzero; see if(home) above */
-	      return 0;		/* no config file available */
+/*        free (home);             home is unallocated; see if(home) above */
+	      return 0;
 	    }
 	}
     }
-  else
-    {
-      strcpy (config_file_name, CONFIGDIR);
-      if (!(f = fopen (config_file_name, "r")))
-	{
-/*        free (home);             home is unallocated; see if(home) above */
-	  return 0;
-	}
-    }
-
   while (!feof (f))
     {
       if (!(fgets (line, 255, f)))
@@ -263,6 +277,14 @@ parse_line (char *line)
 	key = &keys.print_1;
       else if (!strncmp (temp + 4, "PRINT_2", 7))
 	key = &keys.print_2;
+      else if (!strncmp (temp + 4, "LEFT_1", 6))
+	key = &keys.left_1;
+      else if (!strncmp (temp + 4, "LEFT_2", 6))
+	key = &keys.left_2;
+      else if (!strncmp (temp + 4, "RIGHT_1", 7))
+	key = &keys.right_1;
+      else if (!strncmp (temp + 4, "RIGHT_2", 7))
+	key = &keys.right_2;
       else
 	return 1;
     }
@@ -622,6 +644,17 @@ parse_line (char *line)
       else
 	return 1;
     }
+  else if (!strncmp (temp, "INFOPATH", 8))
+    {
+      temp = strtok (NULL, "\n");
+      if (temp)
+	{
+	  configuredinfopath = strdup (temp);
+	  remove_quotes (configuredinfopath);
+	}
+      else
+	return 1;
+    }
 #ifndef ___DONT_USE_REGEXP_SEARCH___
   else if (!strncmp (temp, "HIGHLIGHTREGEXP", 15))
     {
