@@ -33,7 +33,7 @@ RCSID (PKG_VER "$Id: pinfo.c,v 1.36 2000/08/27 19:09:48 pborys Exp $")
   char filename[256];
   WorkRVal work_return_value =
   {0, 0};
-  int i;
+  int i, userdefinedrc = 0;
   int command_line_option;
   FILE *id = NULL;
   long lines = 0;		/* line count in message */
@@ -66,6 +66,11 @@ RCSID (PKG_VER "$Id: pinfo.c,v 1.36 2000/08/27 19:09:48 pborys Exp $")
   searchagain.search = 0;
   initlocale ();
   inithistory ();
+  for (i = 1; i < argc; i++)
+    if (strncmp (argv[i], "--rcfile", 8) == 0)
+      userdefinedrc = 1;
+  if (!userdefinedrc)
+    parse_config ();		/* read config information */
   if (verbose)
     printf ("Przemek's Info Viewer v%s\n", version);
   if (argc == 1)		/* if no arguments were given */
@@ -75,8 +80,8 @@ RCSID (PKG_VER "$Id: pinfo.c,v 1.36 2000/08/27 19:09:48 pborys Exp $")
       strcpy (curfile, "dir");
       strcpy (filename, "dir");
     }
-  if (strlen (argv[0]) >= 3)
-    if (strstr (argv[0], "man") != NULL)	/* handle any 'man' alias to 'pinfo' */
+  if ((strlen (argv[0]) >= 3)||(use_manual))
+    if ((strstr (argv[0], "man") != NULL)||(use_manual))	/* handle any 'man' alias to 'pinfo' */
       {
 	if (verbose)
 	  printf (_ ("Looking for man page...\n"));
@@ -89,6 +94,9 @@ RCSID (PKG_VER "$Id: pinfo.c,v 1.36 2000/08/27 19:09:48 pborys Exp $")
 	  }
 	exit (handlemanual (filename));
       }
+
+
+
 #ifdef HAVE_GETOPT_LONG
 
 /******************************************************************************
@@ -122,6 +130,7 @@ RCSID (PKG_VER "$Id: pinfo.c,v 1.36 2000/08/27 19:09:48 pborys Exp $")
 	      exit (1);
 	    }
 	  rcfile = strdup (optarg);
+	  parse_config ();	/* parse user-defined config file */
 	  break;
 	case 't':
 	  ForceManualTagTable = 1;
@@ -151,8 +160,7 @@ RCSID (PKG_VER "$Id: pinfo.c,v 1.36 2000/08/27 19:09:48 pborys Exp $")
 	case 'v':
 	  exit (0);
 	case 'm':
-	  parse_config ();	/* read config information */
-          checksu ();
+	  checksu ();
 	  if (verbose)
 	    printf (_ ("Looking for man page...\n"));
 	  strcpy (filename, "");
@@ -166,7 +174,7 @@ RCSID (PKG_VER "$Id: pinfo.c,v 1.36 2000/08/27 19:09:48 pborys Exp $")
 	case 'r':
 	  strncpy (filename, argv[argc - 1], 200);
 	  checkfilename (filename);	/* security check */
-	  addrawpath (filename);
+	  addrawpath (filename);	/* add the raw path to searchpath */
 	  tmp = filename + strlen (filename) - 1;
 	  strip_compression_suffix (filename);	/* later, openinfo automaticaly adds them */
 	  while ((tmp > filename) && (*tmp != '/'))
@@ -198,7 +206,7 @@ RCSID (PKG_VER "$Id: pinfo.c,v 1.36 2000/08/27 19:09:48 pborys Exp $")
   while (command_line_option != EOF);
 /*****************************************************************************/
 #endif
-  parse_config ();		/* read config information */
+
   checksu ();
   initpaths ();
 
@@ -219,14 +227,35 @@ RCSID (PKG_VER "$Id: pinfo.c,v 1.36 2000/08/27 19:09:48 pborys Exp $")
       strncpy (filename, argv[argc - 1], 200);	/* the paths will be searched
 						   by openinfo() */
 #endif
+      if(filename[0]=='(')
+        {
+          int fnamelen=strlen(filename);
+          for(i=0;i<fnamelen;i++)	/* erase the leading '(' */
+            filename[i]=filename[i+1];
+          for(i=0;filename[i]!=')';i++);
+          filename[i]=0;		/* leave the filename part in filename */
+          if(!pinfo_start_node)		/* copy the node content to pinfo_start_node */
+            {
+              pinfo_start_node=strdup(&filename[i+1]);
+            }
+        }
+
       checkfilename (filename);	/* security check */
 
+      if((strncmp(filename,"../",3)==0)||	/* autodetect raw filenames */
+         (strncmp(filename,"./",2)==0)||
+         (filename[0]=='/'))
+         {
+           addrawpath(filename);
+         }
+               
       curfile = xmalloc (strlen (filename) + 100);	/* leave some space for
 							   `.info' suffix */
       strcpy (curfile, filename);
     }
 
-  id = openinfo (filename, 0);
+  if(id == NULL)		/* no rawpath has been opened */
+    id = openinfo (filename, 0);
 
   if (id == NULL)		/* try to lookup the name in dir file */
     {
@@ -235,18 +264,6 @@ RCSID (PKG_VER "$Id: pinfo.c,v 1.36 2000/08/27 19:09:48 pborys Exp $")
   if (id == NULL)		/* if still nothing, try to use man page instead */
     {
       printf (_ ("Error: could not open info file, trying manual\n"));
-#ifdef HAVE_GETOPT_LONG
-      if (optind < argc)
-	{
-	  strncpy (filename, argv[optind], 200);	/* security check */
-	}
-      else
-	{
-	  strcpy (filename, "dir");
-	}
-#else
-      strncpy (filename, argv[argc - 1], 200);	/* security check */
-#endif
       exit (handlemanual (filename));
     }
   if (seek_indirect (id))	/* search for indirect entries, if any */
@@ -288,7 +305,7 @@ RCSID (PKG_VER "$Id: pinfo.c,v 1.36 2000/08/27 19:09:48 pborys Exp $")
 					   entries */
 	    {
 	      printf (_ ("This doesn't look like info file...\n"));
-	      return 1;
+	      exit (handlemanual (filename));
 	    }
 	}
       else
